@@ -16,12 +16,12 @@
 #include <katecompletiontree.h>
 #include <katecompletionwidget.h>
 #include <kateconfig.h>
-#include <kateglobal.h>
 #include <katerenderer.h>
 #include <kateview.h>
 
 #include <QApplication>
 #include <QKeyEvent>
+#include <QStandardPaths>
 #include <QTest>
 
 QTEST_MAIN(CompletionTest)
@@ -60,7 +60,7 @@ static void invokeCompletionBox(KTextEditor::ViewPrivate *view)
 
 void CompletionTest::init()
 {
-    KTextEditor::EditorPrivate::enableUnitTestMode();
+    QStandardPaths::setTestModeEnabled(true);
     Editor *editor = KTextEditor::Editor::instance();
     QVERIFY(editor);
 
@@ -235,8 +235,8 @@ void CompletionTest::testAbortControllerMultipleModels()
 
     m_view->insertText(QStringLiteral("-"));
     verifyCompletionStarted(m_view);
-    QVERIFY(!m_view->completionWidget()->completionRanges().contains(testModel1));
-    QVERIFY(m_view->completionWidget()->completionRanges().contains(testModel2));
+    QVERIFY(!m_view->completionWidget()->completionRangesContainsModel(testModel1));
+    QVERIFY(m_view->completionWidget()->completionRangesContainsModel(testModel2));
 
     QCOMPARE(countItems(model), 40);
 
@@ -280,10 +280,6 @@ void CompletionTest::testUpdateCompletionRange()
 
 void CompletionTest::testCustomStartCompl()
 {
-#ifdef __SANITIZE_ADDRESS__
-    QSKIP("issues with Qt 6.5 and sanitizer");
-#endif
-
     KateCompletionModel *model = m_view->completionWidget()->model();
 
     m_view->completionWidget()->setAutomaticInvocationDelay(1);
@@ -407,6 +403,7 @@ void CompletionTest::testTabCompletion()
     m_doc->insertText({0, 0}, QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     verifyCompletionStarted(m_view);
+    QTRY_VERIFY(m_view->completionWidget()->elapsedMSSinceShowing() > m_view->completionWidget()->minRequiredMsToAcceptCompletion());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
     QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
@@ -417,6 +414,7 @@ void CompletionTest::testTabCompletion()
     m_view->completionWidget()->automaticInvocation();
     verifyCompletionStarted(m_view);
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    QTRY_VERIFY(m_view->completionWidget()->elapsedMSSinceShowing() > m_view->completionWidget()->minRequiredMsToAcceptCompletion());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
     QCOMPARE(m_doc->text(), QStringLiteral("aad3"));
@@ -430,6 +428,7 @@ void CompletionTest::testTabCompletion()
     verifyCompletionStarted(m_view);
     // ... Tab will select the first entry
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    QTRY_VERIFY(m_view->completionWidget()->elapsedMSSinceShowing() > m_view->completionWidget()->minRequiredMsToAcceptCompletion());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
     QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
@@ -441,6 +440,7 @@ void CompletionTest::testTabCompletion()
     verifyCompletionStarted(m_view);
     m_view->completionWidget()->cursorDown(); // Select first entry
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Up);
+    QTRY_VERIFY(m_view->completionWidget()->elapsedMSSinceShowing() > m_view->completionWidget()->minRequiredMsToAcceptCompletion());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
     QCOMPARE(m_doc->text(), QStringLiteral("ac\u008738"));
@@ -454,6 +454,7 @@ void CompletionTest::testTabCompletion()
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Up); // Go to bottom
     // While at the bottom, Tab goes to the top of the list
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    QTRY_VERIFY(m_view->completionWidget()->elapsedMSSinceShowing() > m_view->completionWidget()->minRequiredMsToAcceptCompletion());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
     QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
