@@ -12,7 +12,6 @@
 #include <inputmode/kateviinputmode.h>
 #include <kateconfig.h>
 #include <katedocument.h>
-#include <kateglobal.h>
 #include <kateundomanager.h>
 #include <kateview.h>
 #include <vimode/emulatedcommandbar/emulatedcommandbar.h>
@@ -30,13 +29,13 @@ using namespace KTextEditor;
 BaseTest::BaseTest()
 {
     // test mode with e.g. own temporary config files
-    KTextEditor::EditorPrivate::enableUnitTestMode();
+    QStandardPaths::setTestModeEnabled(true);
 
     kate_view = nullptr;
     kate_document = nullptr;
 
     mainWindow = new QMainWindow;
-    auto centralWidget = new QWidget();
+    auto centralWidget = new QWidget(mainWindow);
     mainWindowLayout = new QVBoxLayout(centralWidget);
     mainWindow->setCentralWidget(centralWidget);
     mainWindow->resize(640, 480);
@@ -69,6 +68,7 @@ BaseTest::BaseTest()
 BaseTest::~BaseTest()
 {
     delete kate_document;
+    delete mainWindow;
 }
 
 void BaseTest::waitForCompletionWidgetToActivate(KTextEditor::ViewPrivate *kate_view)
@@ -144,12 +144,12 @@ void BaseTest::TestPressKey(const QString &str)
                 int endOfSpecialKeyAfterModifier = -1;
                 const Qt::Key parsedCodedSpecialKeyAfterModifier = parseCodedSpecialKey(str, i, &endOfSpecialKeyAfterModifier);
                 if (parsedCodedSpecialKeyAfterModifier != Qt::Key_unknown) {
-                    key = parsedCodedSpecialKeyAfterModifier <= 0xffff ? QString(QChar(parsedCodedSpecialKeyAfterModifier)) : QString();
+                    key = parsedCodedSpecialKeyAfterModifier <= 0xffff ? QString(char16_t(parsedCodedSpecialKeyAfterModifier)) : QString();
                     keyCode = parsedCodedSpecialKeyAfterModifier;
                     i = endOfSpecialKeyAfterModifier;
                 }
             } else if (parsedSpecialKey != Qt::Key_unknown) {
-                key = parsedSpecialKey <= 0xffff ? QString(QChar(parsedSpecialKey)) : QString();
+                key = parsedSpecialKey <= 0xffff ? QString(char16_t(parsedSpecialKey)) : QString();
                 keyCode = parsedSpecialKey;
                 i = endOfSpecialKey;
             } else if (str.mid(i, 2) == QStringLiteral("\\:")) {
