@@ -15,10 +15,8 @@
 #include <QTimer>
 
 #include <ktexteditor/document.h>
-#include <ktexteditor/mainwindow.h>
 #include <ktexteditor/movingrangefeedback.h>
 
-#include "katetextline.h"
 #include <ktexteditor_export.h>
 
 #include <span>
@@ -40,6 +38,7 @@ class TransferJob;
 namespace Kate
 {
 class SwapFile;
+class TextLine;
 }
 
 class KateBuffer;
@@ -47,6 +46,7 @@ namespace KTextEditor
 {
 class Message;
 class ViewPrivate;
+class MainWindow;
 }
 class KateDocumentConfig;
 class KateHighlighting;
@@ -542,7 +542,7 @@ public:
 
 private:
     QHash<int, KTextEditor::Mark *> m_marks;
-    QHash<int, QIcon> m_markIcons; // QPixmap or QIcon, KF6: remove QPixmap support
+    QHash<int, QIcon> m_markIcons;
     QHash<int, QString> m_markDescriptions;
     uint m_editableMarks = markType01;
 
@@ -808,7 +808,7 @@ public:
     void transpose(const KTextEditor::Cursor);
     void swapTextRanges(KTextEditor::Range firstWord, KTextEditor::Range secondWord);
     bool multiPaste(KTextEditor::ViewPrivate *view, const QStringList &texts);
-    void paste(KTextEditor::ViewPrivate *view, const QString &text);
+    void paste(KTextEditor::ViewPrivate *view, QString text);
 
 public:
     enum CommentType {
@@ -1121,6 +1121,11 @@ public:
     //
     // REALLY internal data ;)
     //
+    //
+public:
+    // File Dialog Helper
+    QUrl startUrlForFileDialog();
+
 private:
     // text buffer
     KateBuffer *const m_buffer;
@@ -1276,8 +1281,13 @@ private:
     // END KTextEditor::MessageInterface
 
 public:
+    struct DictionaryRange {
+        KTextEditor::MovingRange *range;
+        QString dictionary;
+    };
+
     QString defaultDictionary() const;
-    QList<QPair<KTextEditor::MovingRange *, QString>> dictionaryRanges() const;
+    QList<DictionaryRange> dictionaryRanges() const;
     bool isOnTheFlySpellCheckingEnabled() const;
     KateOnTheFlyChecker *onTheFlySpellChecker() const
     {
@@ -1299,26 +1309,10 @@ Q_SIGNALS:
     void dictionaryRangesPresent(bool yesNo);
     void defaultDictionaryChanged(KTextEditor::DocumentPrivate *document);
 
-public:
-    bool containsCharacterEncoding(KTextEditor::Range range);
-
-    typedef QList<QPair<int, int>> OffsetList;
-
-    static int computePositionWrtOffsets(const OffsetList &offsetList, int pos);
-
-    /**
-     * The first OffsetList is from decoded to encoded, and the second OffsetList from
-     * encoded to decoded.
-     **/
-    QString decodeCharacters(KTextEditor::Range range,
-                             KTextEditor::DocumentPrivate::OffsetList &decToEncOffsetList,
-                             KTextEditor::DocumentPrivate::OffsetList &encToDecOffsetList);
-    void replaceCharactersByEncoding(KTextEditor::Range range);
-
 protected:
     KateOnTheFlyChecker *m_onTheFlyChecker = nullptr;
     QString m_defaultDictionary;
-    QList<QPair<KTextEditor::MovingRange *, QString>> m_dictionaryRanges;
+    QList<DictionaryRange> m_dictionaryRanges;
 
     // from KTextEditor::MovingRangeFeedback
     void rangeInvalid(KTextEditor::MovingRange *movingRange) override;
