@@ -8,20 +8,23 @@
 #ifndef KATELAYOUTCACHE_H
 #define KATELAYOUTCACHE_H
 
-#include <QPair>
-
 #include <ktexteditor/range.h>
 
 #include "katetextlayout.h"
 
+#include <memory_resource>
+
 class KateRenderer;
 
 class KateLineLayoutMap
 {
 public:
+    KateLineLayoutMap(std::pmr::unsynchronized_pool_resource &allocator);
+    ~KateLineLayoutMap();
+
     void clear();
 
-    void insert(int realLine, std::unique_ptr<KateLineLayout> lineLayoutPtr);
+    void insert(KateLineLayout *lineLayoutPtr);
 
     void relayoutLines(int startRealLine, int endRealLine);
 
@@ -29,11 +32,9 @@ public:
 
     KateLineLayout *find(int i);
 
-    typedef std::pair<int, std::unique_ptr<KateLineLayout>> LineLayoutPair;
-
 private:
-    typedef std::vector<LineLayoutPair> LineLayoutMap;
-    LineLayoutMap m_lineLayouts;
+    std::vector<KateLineLayout *> m_lineLayouts;
+    std::pmr::unsynchronized_pool_resource &m_allocator;
 };
 
 /**
@@ -136,6 +137,8 @@ private:
 private:
     KateRenderer *m_renderer;
 
+    std::pmr::unsynchronized_pool_resource m_allocator;
+
     /**
      * The master cache of all line layouts.
      *
