@@ -655,7 +655,7 @@ void KateRenderer::paintTextLine(QPainter &paint,
     const Kate::TextLine textLine = doc()->kateTextLine(range->line());
 
     int currentViewLine = -1;
-    if (cursor && cursor->line() == range->line()) {
+    if (cursor && cursor->line() == range->line() && m_view && m_view->isHighlightCurrentLineActive()) {
         currentViewLine = range->viewLineForColumn(cursor->column());
     }
 
@@ -715,7 +715,7 @@ void KateRenderer::paintTextLine(QPainter &paint,
         // Check if we are at a bracket and color the indentation
         // line differently
         const bool indentLinesEnabled = showIndentLines();
-        if (cursor && indentLinesEnabled) {
+        if (cursor && indentLinesEnabled && m_view && m_view->isBracketMatchHighlightActive()) {
             auto cur = *cursor;
             cur.setColumn(cur.column() - 1);
             if (!m_currentBracketRange.boundaryAtCursor(*cursor) && m_currentBracketRange.end() != cur && m_currentBracketRange.start() != cur) {
@@ -874,7 +874,7 @@ void KateRenderer::paintTextLine(QPainter &paint,
         }
 
         // Draw carets
-        if (m_view && cursor && drawCaret()) {
+        if (m_view && cursor && drawCaret() && m_view->isCursorVisible()) {
             const auto &secCursors = view()->secondaryCursors();
             // Find carets on this line
             auto mIt = std::lower_bound(secCursors.begin(), secCursors.end(), range->line(), [](const KTextEditor::ViewPrivate::SecondaryCursor &l, int line) {
