@@ -15,6 +15,7 @@
 #include "katecmd.h"
 #include "katedocument.h"
 #include "katepartdebug.h"
+#include "kateview.h"
 
 KateCommandLineScript::KateCommandLineScript(const QString &url, const KateCommandLineScriptHeader &header)
     : KateScript(url)
@@ -23,10 +24,6 @@ KateCommandLineScript::KateCommandLineScript(const QString &url, const KateComma
 {
 }
 
-KateCommandLineScript::~KateCommandLineScript()
-{
-}
-
 const KateCommandLineScriptHeader &KateCommandLineScript::commandHeader()
 {
     return m_commandHeader;
@@ -60,8 +57,9 @@ bool KateCommandLineScript::callFunction(const QString &cmd, const QStringList &
 
 bool KateCommandLineScript::exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &range)
 {
-    if (range.isValid())
+    if (range.isValid()) {
         view->setSelection(range);
+    }
 
     KShell::Errors errorCode;
     QStringList args(KShell::splitArgs(cmd, KShell::NoOptions, &errorCode));
