@@ -10,16 +10,13 @@
 #include <ktexteditor_export.h>
 
 #include <ktexteditor/document.h>
-#include <ktexteditor/view.h>
 
-#include <functional>
 #include <map>
 #include <memory>
 
 #include <QBitArray>
 #include <QColor>
 #include <QList>
-#include <QObject>
 
 class KConfigGroup;
 namespace KTextEditor
@@ -147,7 +144,7 @@ protected:
          * @param defaultVal default value
          * @param valid validator function, default none
          */
-        ConfigEntry(int enumId, const char *configId, QString command, QVariant defaultVal, std::function<bool(const QVariant &)> valid = nullptr)
+        ConfigEntry(int enumId, const char *configId, QString command, QVariant defaultVal, bool (*valid)(const QVariant &) = nullptr)
             : enumKey(enumId)
             , configKey(configId)
             , commandName(command)
@@ -189,7 +186,7 @@ protected:
          * we accept a given new value.
          * Is no validator set, we accept any value.
          */
-        std::function<bool(const QVariant &)> validator;
+        bool (*validator)(const QVariant &);
     };
 
     /**
@@ -542,6 +539,11 @@ public:
          */
         AutoReloadIfStateIsInVersionControl,
 
+        /**
+         * Should we auto-reload if any external changes occur?
+         */
+        AutoReloadOnExternalChanges,
+
         /**
          * Should we use editorconfig
          */
@@ -1054,6 +1056,9 @@ public:
         ShowStatusbarEOL,
         EnableAccessibility,
         CycleThroughBookmarks,
+        DisableCurrentLineHighlightIfInactive,
+        HideCursorIfInactive,
+        DisableBracketMatchHighlightIfInactive,
     };
 
 public:
@@ -1230,11 +1235,6 @@ public:
         return value(PersistentSelection).toBool();
     }
 
-    KTextEditor::View::InputMode inputMode() const
-    {
-        return static_cast<KTextEditor::View::InputMode>(value(InputMode).toUInt());
-    }
-
     bool viInputModeStealKeys() const
     {
         return value(ViInputModeStealKeys).toBool();
