@@ -5,11 +5,11 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "definitions.h"
 #include <QKeyEvent>
 #include <QStringList>
 #include <vimode/keyevent.h>
 #include <vimode/keyparser.h>
-#include "definitions.h"
 
 using namespace KateVi;
 
@@ -570,7 +570,7 @@ const QString KeyParser::encodeKeySequence(const QString &keys) const
                                     endOfBlock = keys.length() - 1;
                                 }
                                 encodedSequence.clear();
-                                encodedSequence.append(QChar(m_nameToKeyCode.value(QStringLiteral("invalid"))));
+                                encodedSequence.append(QChar::fromUcs4(m_nameToKeyCode.value(QStringLiteral("invalid"))));
                                 break;
                             }
                         }
@@ -653,7 +653,7 @@ const QString KeyParser::decodeKeySequence(const QString &keys) const
             if ((keycode & 0xE000) == 0xE000) {
                 ret.append(m_keyCodeToName.value((keycode - 0xE000) / 0x10));
             } else {
-                ret.append(QChar(keycode));
+                ret.append(QChar::fromUcs4(keycode));
             }
             ret.append(QLatin1Char('>'));
         }
@@ -672,7 +672,7 @@ const QChar KeyParser::KeyEventToQChar(const KeyEvent &keyEvent)
     return KeyEventToQChar(keyEvent.key(), keyEvent.text(), keyEvent.modifiers());
 }
 
-const QChar KeyParser::KeyEventToQChar(int keyCode, const QString &text, Qt::KeyboardModifiers mods)
+const QChar KeyParser::KeyEventToQChar(int keyCode, const QString &text, Qt::KeyboardModifiers mods) const
 {
     // If previous key press was AltGr, return key value right away and don't go
     // down the "handle modifiers" code path. AltGr is really confusing...
